@@ -208,7 +208,7 @@ def validator(field: str, func: Callable = None):
     return decorator
 
 
-@lru_cache
+@lru_cache(maxsize=None)
 def get_func_validator(func: Callable):
     signature = inspect.signature(func)
     parameters = signature.parameters
